Package 'accumulate'
| Title: |
Split-Apply-Combine with Dynamic Groups |
| Description: |
Estimate group aggregates, where one can set user-defined
conditions that each group of records must satisfy to be
suitable for aggregation. If a group of records is not
suitable, it is expanded using a collapsing scheme defined by
the user. A paper on this package was published in the Journal
of Statistical Software <doi:10.18637/jss.v112.i04>. |
| Authors: |
Mark van der Loo [aut, cre] (ORCID:
<https://orcid.org/0000-0002-9807-4686>) |
| Maintainer: |
Mark van der Loo <[email protected]> |
| License: |
EUPL |
| Version: |
1.0.0 |
| Built: |
2026-05-16 06:10:05 UTC |
| Source: |
https://github.com/markvanderloo/accumulate |
Help Index